@@ -18,21 +18,21 @@ the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 */
 
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qcombobox.h>
+#include "imgallerydialog.h"
 
-#include <qcheckbox.h>
-#include <qlineedit.h>
-#include <qspinbox.h>
-//Added by qt3to4:
+#include <QLabel>
+#include <QLayout>
+#include <QComboBox>
+#include <QCheckBox>
+#include <QLineEdit>
+#include <QSpinBox>
 #include <QVBoxLayout>
 #include <QFrame>
 #include <QHBoxLayout>
 #include <QGridLayout>
+#include <QFontDatabase>
 
 #include <KLocalizedString>
-#include <kurl.h>
 #include <kfontdialog.h>
 #include <kiconloader.h>
 #include <klineedit.h>
@@ -40,10 +40,6 @@ Boston, MA 02110-1301, USA.
 #include <kcolorbutton.h>
 #include <kurlrequester.h>
 #include <kconfig.h>
-#include <KIcon>
-
-#include <QFontDatabase>
-#include "imgallerydialog.h"
 
 KIGPDialog::KIGPDialog(QWidget *parent, const QString &path)
     : KPageDialog(parent)
@@ -95,7 +91,7 @@ void KIGPDialog::setupLookPage(const QString &path)
     QFrame *page = new QFrame();
     KPageWidgetItem *pageItem = new KPageWidgetItem(page, i18n("Look"));
     pageItem->setHeader(i18n("Page Look"));
-    pageItem->setIcon(KIcon(BarIcon("fill-color", KIconLoader::SizeMedium)));
+    pageItem->setIcon(QIcon::fromTheme("fill-color"));
     addPage(pageItem);
 
     KConfigGroup look = m_config->group("Look");
@@ -194,7 +190,7 @@ void KIGPDialog::setupDirectoryPage(const QString &path)
     QFrame *page = new QFrame();
     KPageWidgetItem *pageItem = new KPageWidgetItem(page, i18n("Folders"));
     pageItem->setHeader(i18n("Folders"));
-    pageItem->setIcon(KIcon(BarIcon("folder", KIconLoader::SizeMedium)));
+    pageItem->setIcon(QIcon::fromTheme("folder"));
     addPage(pageItem);
 
     KConfigGroup group =  m_config->group("Directory");
@@ -297,7 +293,7 @@ void KIGPDialog::setupThumbnailPage(const QString &path)
     QFrame *page = new QFrame();
     KPageWidgetItem *pageItem = new KPageWidgetItem(page, i18n("Thumbnails"));
     pageItem->setHeader(i18n("Thumbnails"));
-    pageItem->setIcon(KIcon(BarIcon("view-preview", KIconLoader::SizeMedium)));
+    pageItem->setIcon(QIcon::fromTheme("view-preview"));
     addPage(pageItem);
 
     KConfigGroup group =  m_config->group("Thumbnails");
@@ -450,14 +446,14 @@ const QString KIGPDialog::getTitle() const
     return m_title->text();
 }
 
-const KUrl KIGPDialog::getImageUrl() const
+const QUrl KIGPDialog::getImageUrl() const
 {
     return m_imageNameReq->url();
 }
 
 const QString KIGPDialog::getCommentFile() const
 {
-    return m_commentFileReq->url().path();
+    return m_commentFileReq->url().toLocalFile();
 }
 
 const QString KIGPDialog::getFontName() const
