@@ -14,13 +14,12 @@
 // std
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 
 // Qt
-#include <QtCore/QRegExp>
-#include <QtCore/QTextStream>
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusMessage>
+#include <QRegExp>
+#include <QTextStream>
+#include <QDBusConnection>
+#include <QDBusMessage>
 #include <QLabel>
 #include <QSlider>
 #include <QTreeWidget>
